namespace Eco.Mods.TechTree
{
    using System;
    using System.Collections.Generic;
    using Eco.Core.Items;
    using Eco.Gameplay.Components;
    using Eco.Gameplay.Components.Auth;
    using Eco.Gameplay.Items;
    using Eco.Gameplay.Objects;
    using Eco.Shared.Localization;
    using Eco.Shared.Serialization;

    [Serialized]
    [LocDisplayName("Bicycle Brown")]
    [Weight(5000)]
    [Ecopedia("CavRnMods", "Bicycle", true, InPageTooltip.DynamicTooltip)]
    [Tag("ColoredBicycle")]
    public partial class BicycleBrownItem : WorldObjectItem<BicycleBrownObject>
    {
        public override LocString DisplayDescription { get { return Localizer.DoStr("A brown bicycle for fast travel."); } }
    }
    
    public class PaintBicycleBrownRecipe : RecipeFamily
    {
        public PaintBicycleBrownRecipe()
        {
            this.Recipes = new List<Recipe>
            {
                new Recipe(
                    "Paint Bicycle Brown",
                    Localizer.DoStr("Paint Bicycle Brown"),
                    new IngredientElement[]
                    {
                        new IngredientElement(typeof(BicycleItem), 1, true), 
                        new IngredientElement(typeof(ClayItem), 3, typeof(MechanicsSkill), typeof(MechanicsLavishResourcesTalent)),                       
                    },
                    new CraftingElement<BicycleBrownItem>()
                )
            };
            this.ExperienceOnCraft = 0.05f;  
            this.LaborInCalories = CreateLaborInCaloriesValue(125, typeof(MechanicsSkill)); 
            this.CraftMinutes = CreateCraftTimeValue(typeof(PaintBicycleBrownRecipe), 2.5f, typeof(MechanicsSkill));    

            this.Initialize(Localizer.DoStr("Paint Bicycle Brown"), typeof(PaintBicycleBrownRecipe));
            CraftingComponent.AddRecipe(typeof(AdvancedPaintingTableObject), this);
        }
    }

    [Serialized]
    [RequireComponent(typeof(StandaloneAuthComponent))]
    [RequireComponent(typeof(VehicleComponent))]
    public partial class BicycleBrownObject : PhysicsWorldObject, IRepresentsItem
    {
        static BicycleBrownObject()
        {
            WorldObject.AddOccupancy<BicycleBrownObject>(new List<BlockOccupancy>(0));
        }

        public override LocString DisplayName { get { return Localizer.DoStr("Bicycle Brown"); } }
        public Type RepresentedItemType { get { return typeof(BicycleBrownItem); } }

        
        private BicycleBrownObject() { }

        protected override void Initialize()
        {
            base.Initialize();

            this.GetComponent<VehicleComponent>().Initialize(22, 0, 1);
            this.GetComponent<VehicleComponent>().HumanPowered(0.25f);           
        }
    }
}
