namespace Eco.Mods.TechTree
{
    using System;
    using System.Collections.Generic;
    using Eco.Core.Items;
    using Eco.Gameplay.Components;
    using Eco.Gameplay.Components.Auth;
    using Eco.Gameplay.Items;
    using Eco.Gameplay.Objects;
    using Eco.Shared.Localization;
    using Eco.Shared.Serialization;

    [Serialized]
    [LocDisplayName("Bicycle Green")]
    [Weight(5000)]
    [Ecopedia("CavRnMods", "Bicycle", true, InPageTooltip.DynamicTooltip)]
    [Tag("ColoredBicycle")]
    public partial class BicycleGreenItem : WorldObjectItem<BicycleGreenObject>
    {
        public override LocString DisplayDescription { get { return Localizer.DoStr("A green bicycle for fast travel."); } }
    }
    
    public class PaintBicycleGreenRecipe : RecipeFamily
    {
        public PaintBicycleGreenRecipe()
        {
            this.Recipes = new List<Recipe>
            {
                new Recipe(
                    "Paint Bicycle Green",
                    Localizer.DoStr("Paint Bicycle Green"),
                    new IngredientElement[]
                    {
                        new IngredientElement(typeof(BicycleItem), 1, true), 
                        new IngredientElement(typeof(KelpItem), 10, typeof(MechanicsSkill), typeof(MechanicsLavishResourcesTalent)),                       
                    },
                    new CraftingElement<BicycleGreenItem>()
                )
            };
            this.ExperienceOnCraft = 0.05f;  
            this.LaborInCalories = CreateLaborInCaloriesValue(125, typeof(MechanicsSkill)); 
            this.CraftMinutes = CreateCraftTimeValue(typeof(PaintBicycleGreenRecipe), 2.5f, typeof(MechanicsSkill));    

            this.Initialize(Localizer.DoStr("Paint Bicycle Green"), typeof(PaintBicycleGreenRecipe));
            CraftingComponent.AddRecipe(typeof(AdvancedPaintingTableObject), this);
        }
    }

    [Serialized]
    [RequireComponent(typeof(StandaloneAuthComponent))]
    [RequireComponent(typeof(VehicleComponent))]
    public partial class BicycleGreenObject : PhysicsWorldObject, IRepresentsItem
    {
        static BicycleGreenObject()
        {
            WorldObject.AddOccupancy<BicycleGreenObject>(new List<BlockOccupancy>(0));
        }

        public override LocString DisplayName { get { return Localizer.DoStr("Bicycle Green"); } }
        public Type RepresentedItemType { get { return typeof(BicycleGreenItem); } }

        
        private BicycleGreenObject() { }

        protected override void Initialize()
        {
            base.Initialize();

            this.GetComponent<VehicleComponent>().Initialize(22, 0, 1);
            this.GetComponent<VehicleComponent>().HumanPowered(0.25f);           
        }
    }
}
